/*
    The PC (preconditioner) interface routines, callable by users.
*/
#include "pc.h" /* VE this shoudln't be, but it gets taken from petsc, not parpre */
#include "src/pc/pcimpl.h"            /*I "pc.h" I*/

#undef __FUNC__
#define __FUNC__ "PCIsParallel"
int PCIsParallel(PC pc) /* VE */
{
  if (pc->type >= PCAdditiveSchwarz) return 1;
  else return 0;
}

#undef __FUNC__
#define __FUNC__ "PCIsSchwarzMethod"
int PCIsSchwarzMethod(PC pc) /* VE */
{
  if ((pc->type==PCAdditiveSchwarz) | (pc->type==PCMultiplicativeSchwarz))
    return 1;
  else return 0;
}

